package com.ynet.life.security.crypto;

import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeDBAccess;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.security.Security;
import java.sql.Connection;
import java.util.ArrayList;
import java.util.List;
import javax.crypto.Cipher;
import javax.crypto.CipherInputStream;
import javax.crypto.CipherOutputStream;
import javax.crypto.NoSuchPaddingException;
import javax.crypto.spec.SecretKeySpec;
import org.bouncycastle.jce.provider.BouncyCastleProvider;
import org.bouncycastle.util.encoders.Hex;

public class AESCrypto {

   private static final String SQL_SECRET_KEY = "SELECT KEY_VALUE FROM SECRET_KEY WHERE KEY_TYPE = ?";


   static {
      try {
         if(Security.getProvider("BC") == null) {
            Security.addProvider(new BouncyCastleProvider());
            return;
         }
      } catch (Exception var1) {
         System.err.println("Cannot load security provider: BC \n" + var1.getMessage());
      }

   }

   public static String getRandomHexString(int intSize) {
      String str = "";
      String charSet = "0123456789abcdef";

      for(int i = 0; i < intSize << 1; ++i) {
         int intLoc = (int)Math.floor(Math.random() * (double)charSet.length());
         str = str + charSet.substring(intLoc, intLoc + 1);
      }

      return str;
   }

   public static SecretKeySpec getAESKeySpecFromString(String strKey) throws NoSuchAlgorithmException, InvalidKeyException {
      return new SecretKeySpec(strKey.getBytes(), "AES");
   }

   public static SecretKeySpec getKeySpecFromBytes(String strBytes) throws NoSuchAlgorithmException {
      return new SecretKeySpec(Hex.decode(strBytes.getBytes()), "AES");
   }

   public static String getAESKeyStringForJS(String spec) throws NoSuchAlgorithmException {
      SecretKeySpec spec1 = getKeySpecFromBytes(spec);
      return new String(Hex.encode(spec1.getEncoded()));
   }

   public static String encryptForJS(String byteEnc, String text) throws Exception {
      Cipher cipher = Cipher.getInstance("AES/ECB/NoPadding", "BC");
      SecretKeySpec byteEnc1 = getKeySpecFromBytes(byteEnc.toUpperCase());
      cipher.init(1, byteEnc1);
      byte[] byteEnc2 = cipher.doFinal(text.getBytes("UTF-8"));
      return new String(Hex.encode(byteEnc2));
   }

   public static String decryptForJS(String spec, String text) throws Exception {
      Cipher cipher = Cipher.getInstance("AES/ECB/NoPadding", "BC");
      SecretKeySpec spec1 = getKeySpecFromBytes(spec.toUpperCase());
      cipher.init(2, spec1);
      return new String(cipher.doFinal(Hex.decode(text.getBytes("UTF-8"))));
   }

   public static String decrypt(SecretKeySpec key, String text) throws Exception {
      Cipher cipher;
      (cipher = Cipher.getInstance("AES")).init(2, key);
      return new String(cipher.doFinal(Hex.decode(text.getBytes("UTF-8"))));
   }

   public static String encrypt(SecretKeySpec byteEnc, String text) throws Exception {
      Cipher cipher;
      (cipher = Cipher.getInstance("AES")).init(1, byteEnc);
      byte[] byteEnc1 = cipher.doFinal(text.getBytes("UTF-8"));
      return new String(Hex.encode(byteEnc1));
   }

   public static String decrypt(String spec, String text) throws Exception {
      Cipher cipher = Cipher.getInstance("AES");
      SecretKeySpec spec1 = getAESKeySpecFromString(spec.toUpperCase());
      cipher.init(2, spec1);
      return new String(cipher.doFinal(Hex.decode(text.getBytes("UTF-8"))));
   }

   public static String encrypt(String byteEnc, String text) throws Exception {
      Cipher cipher = Cipher.getInstance("AES");
      SecretKeySpec byteEnc1 = getAESKeySpecFromString(byteEnc.toUpperCase());
      cipher.init(1, byteEnc1);
      byte[] byteEnc2 = cipher.doFinal(text.getBytes("UTF-8"));
      return new String(Hex.encode(byteEnc2));
   }

   public static void encryptFile(String is, File os, File out) throws IOException, InvalidKeyException, NoSuchAlgorithmException, NoSuchPaddingException {
      Cipher aesCipher = Cipher.getInstance("AES");
      SecretKeySpec is1 = getKeySpecFromBytes(is.toUpperCase());
      aesCipher.init(1, is1);
      FileInputStream is2 = new FileInputStream(os);
      CipherOutputStream os1 = new CipherOutputStream(new FileOutputStream(out), aesCipher);
      copy(is2, os1);
      os1.close();
   }

   public static void decryptFile(String is, File os, File out) throws IOException, InvalidKeyException, NoSuchAlgorithmException, NoSuchPaddingException {
      Cipher aesCipher = Cipher.getInstance("AES");
      SecretKeySpec is1 = getKeySpecFromBytes(is.toUpperCase());
      aesCipher.init(2, is1);
      CipherInputStream is2 = new CipherInputStream(new FileInputStream(os), aesCipher);
      FileOutputStream os1 = new FileOutputStream(out);
      copy(is2, os1);
      is2.close();
      os1.close();
   }

   private static void copy(InputStream is, OutputStream os) throws IOException {
      byte[] b = new byte[1024];

      int i;
      while((i = is.read(b)) != -1) {
         os.write(b, 0, i);
      }

   }

   public static String getDecryptStr(String value, String keyType) throws GENEException {
      try {
         return decrypt((String)getKey(keyType), value);
      } catch (Exception var2) {
         var2.printStackTrace();
         return value;
      }
   }

   public static String getKey(String resultList) throws GENEException {
      Connection connection = null;

      try {
         connection = LifeDBAccess.getConnection();
         ArrayList inputList = new ArrayList();
         new ArrayList();
         inputList.add(resultList);
         List resultList1;
         if((resultList1 = LifeDBAccess.queryMultipleResult(connection, "SELECT KEY_VALUE FROM SECRET_KEY WHERE KEY_TYPE = ?", inputList, 1)).size() <= 0) {
            return null;
         }

         resultList = (String)((List)resultList1.get(0)).get(0);
      } catch (Exception var5) {
         var5.printStackTrace();
         return null;
      } finally {
         LifeDBAccess.releaseConnection(connection);
      }

      return resultList;
   }

   public static void main(String[] deStr) throws Exception {
      try {
         String deStr1 = "lincy@163.com|25|1|||lincy|210.55.33.48|23";
         deStr1 = encrypt((SecretKeySpec)getAESKeySpecFromString("A6F84A769AAAEA3E"), deStr1);
         System.out.println(deStr1);
         deStr1 = decrypt((SecretKeySpec)getAESKeySpecFromString("A6F84A769AAAEA3E"), deStr1);
         System.out.println(deStr1.replaceAll("\r\n", ""));
      } catch (Exception var1) {
         var1.printStackTrace();
      }
   }
}
